# tiny-modal-testy v1.0.9

A modal component for Reactjs application.

## Installation

```bash
npm i tiny-modal-testy
```

## Usage

The modal component is simple :

-   it displays an array of messages
-   it can be closed with a click on a top-right cross or outside.
-   it can be customed with some css properties

Here is an usage example :

```typescript
import { Modal } from "tiny-modal-testy";

import { useState } from "react";
import CreateEmpFormZone from "../CreateEmployeeForm/CreateEmpFormZone";
import FormModal from "../FormModal/FormModal";
import "./HomePage.css";

interface formModalInfos {
    isSuccess: boolean;
    isOpen: boolean;
}

export const MyComponent = () => {
    // A modal opening state
    const [isOpen, setIsOpen] = useState<boolean>(false);

    // You have to add an handler for the modal opening
    const handleModalOpening = () => {
        setIsOpen(!isOpen);
    };

    const getMessages = (): string[] => {
        return ["Employee successfully created !"];
    };

    // All of these are optional
    const modalCSSProperties = {
        zIndex: 1000,
        backgroundColor: "#eff9bd",
        color: "black",
        fontWeight: 400,
    };
    // All of these are optional
    const closeModalCSSProperties = {
        backgroundColor: "transparent",
        color: "#6c850f",
    };
    // If true, add a "shadow" around the modal
    const backgroundShadow: boolean = true;

    return (
        <main>
            <Modal
                isOpen={isOpen}
                modalMessages={getMessages()}
                closeModal={closeModal}
                modalCSSProperties={modalCSSProperties}
                closeModalCSSProperties={closeModalCSSProperties}
                backGroundShadow={backgroundShadow}
            />
        </main>
    );
};
```

## Props details

| Prop          |    Type    |                                                                                                   Description |
| ------------- | :--------: | ------------------------------------------------------------------------------------------------------------: |
| isOpen        |  boolean   |                                                                               If true, the modal is displayed |
| modalMessages | string []  |                                                                  The array of messages displayed in the modal |
| closeModal    | ()=>{void} | The function that closes the modal. You can add any other action you want to trigger when the modal is closed |

## License

[MIT](https://choosealicense.com/licenses/mit/)
